FileStatus
==========

.. currentmodule:: hdfs_native

.. autoclass:: FileStatus
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~FileStatus.access_time
      ~FileStatus.blocksize
      ~FileStatus.group
      ~FileStatus.isdir
      ~FileStatus.length
      ~FileStatus.modification_time
      ~FileStatus.owner
      ~FileStatus.path
      ~FileStatus.permission
      ~FileStatus.replication

   .. rubric:: Attributes Documentation

   .. autoattribute:: access_time
   .. autoattribute:: blocksize
   .. autoattribute:: group
   .. autoattribute:: isdir
   .. autoattribute:: length
   .. autoattribute:: modification_time
   .. autoattribute:: owner
   .. autoattribute:: path
   .. autoattribute:: permission
   .. autoattribute:: replication
